@@ -252,7 +252,7 @@ class ClassRemapperTest extends AsmTest {
             classNode,
             new Remapper(/* latest */ Opcodes.ASM10_EXPERIMENTAL) {
               @Override
-              public String mapInvokeDynamicMethodName(
+              public String mapBasicInvokeDynamicMethodName(
                   final String name,
                   final String descriptor,
                   final Handle bootstrapMethodHandle,
@@ -291,12 +291,14 @@ class ClassRemapperTest extends AsmTest {
   @Test
   void testInvokeDynamicInsn_field_deprecated() {
     ClassNode classNode = new ClassNode();
+    @SuppressWarnings("deprecation")
     ClassRemapper classRemapper =
         new ClassRemapper(
             /* latest api */ Opcodes.ASM9,
             classNode,
             new Remapper() {
               @Override
+              @Deprecated
               public String mapInvokeDynamicMethodName(final String name, final String descriptor) {
                 return "new." + name;
               }
@@ -335,7 +337,7 @@ class ClassRemapperTest extends AsmTest {
             classNode,
             new Remapper(/* latest */ Opcodes.ASM10_EXPERIMENTAL) {
               @Override
-              public String mapInvokeDynamicMethodName(
+              public String mapBasicInvokeDynamicMethodName(
                   final String name,
                   final String descriptor,
                   final Handle bootstrapMethodHandle,
@@ -542,7 +544,7 @@ class ClassRemapperTest extends AsmTest {
     }
 
     @Override
-    public String mapInvokeDynamicMethodName(
+    public String mapBasicInvokeDynamicMethodName(
         final String name,
         final String descriptor,
         final Handle bootstrapMethodHandle,
