@@ -41,6 +41,7 @@ import static org.junit.jupiter.api.Assumptions.assumeTrue;
 import java.io.IOException;
 import java.io.InputStream;
 import java.time.Duration;
+import java.util.Base64;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -418,13 +419,19 @@ class ClassReaderTest extends AsmTest implements Opcodes {
           }
 
           @Override
-          public void visitNestHost(final String nestHost) {}
+          public void visitNestHost(final String nestHost) {
+            // Skip nest host.
+          }
 
           @Override
-          public void visitNestMember(final String nestMember) {}
+          public void visitNestMember(final String nestMember) {
+            // Skip nest member.
+          }
 
           @Override
-          public void visitPermittedSubclass(final String permittedSubclass) {}
+          public void visitPermittedSubclass(final String permittedSubclass) {
+            // Skip permitted subclass.
+          }
         };
 
     Executable accept = () -> classReader.accept(classVisitor, 0);
@@ -630,6 +637,17 @@ class ClassReaderTest extends AsmTest implements Opcodes {
     assertEquals(Opcodes.V_PREVIEW, classVersion.get() & Opcodes.V_PREVIEW);
   }
 
+  @Test
+  void testAccept_invalidCustomAttribute() {
+    byte[] input = Base64.getDecoder().decode("IftdBAAAAAAAAgEAAAD/AAAAAAAAAAAAAAIBAAF/////");
+    ClassReader reader = new ClassReader(input);
+    ClassVisitor noOpVisitor = new ClassVisitor(Opcodes.ASM9) {};
+
+    Executable accept = () -> reader.accept(noOpVisitor, ClassReader.EXPAND_FRAMES);
+
+    assertThrows(IllegalArgumentException.class, accept);
+  }
+
   private static class EmptyClassVisitor extends ClassVisitor {
 
     final AnnotationVisitor annotationVisitor =
